==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/PlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PlatformSpecFluent<A extends PlatformSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAlibabaCloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlibabaCloudPlatformSpec getAlibabaCloud();
  public AlibabaCloudPlatformSpec buildAlibabaCloud();
  public A withAlibabaCloud(AlibabaCloudPlatformSpec alibabaCloud);
  public Boolean hasAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> withNewAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> withNewAlibabaCloudLike(AlibabaCloudPlatformSpec item);
  public PlatformSpecFluent.AlibabaCloudNested<A> editAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> editOrNewAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> editOrNewAlibabaCloudLike(AlibabaCloudPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildAws instead.
   * @return The buildable object.
   */
  @Deprecated
  public AWSPlatformSpec getAws();
  public AWSPlatformSpec buildAws();
  public A withAws(AWSPlatformSpec aws);
  public Boolean hasAws();
  public PlatformSpecFluent.AwsNested<A> withNewAws();
  public PlatformSpecFluent.AwsNested<A> withNewAwsLike(AWSPlatformSpec item);
  public PlatformSpecFluent.AwsNested<A> editAws();
  public PlatformSpecFluent.AwsNested<A> editOrNewAws();
  public PlatformSpecFluent.AwsNested<A> editOrNewAwsLike(AWSPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildAzure instead.
   * @return The buildable object.
   */
  @Deprecated
  public AzurePlatformSpec getAzure();
  public AzurePlatformSpec buildAzure();
  public A withAzure(AzurePlatformSpec azure);
  public Boolean hasAzure();
  public PlatformSpecFluent.AzureNested<A> withNewAzure();
  public PlatformSpecFluent.AzureNested<A> withNewAzureLike(AzurePlatformSpec item);
  public PlatformSpecFluent.AzureNested<A> editAzure();
  public PlatformSpecFluent.AzureNested<A> editOrNewAzure();
  public PlatformSpecFluent.AzureNested<A> editOrNewAzureLike(AzurePlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildBaremetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public BareMetalPlatformSpec getBaremetal();
  public BareMetalPlatformSpec buildBaremetal();
  public A withBaremetal(BareMetalPlatformSpec baremetal);
  public Boolean hasBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> withNewBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> withNewBaremetalLike(BareMetalPlatformSpec item);
  public PlatformSpecFluent.BaremetalNested<A> editBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> editOrNewBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> editOrNewBaremetalLike(BareMetalPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildEquinixMetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public EquinixMetalPlatformSpec getEquinixMetal();
  public EquinixMetalPlatformSpec buildEquinixMetal();
  public A withEquinixMetal(EquinixMetalPlatformSpec equinixMetal);
  public Boolean hasEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> withNewEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> withNewEquinixMetalLike(EquinixMetalPlatformSpec item);
  public PlatformSpecFluent.EquinixMetalNested<A> editEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> editOrNewEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> editOrNewEquinixMetalLike(EquinixMetalPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildGcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPPlatformSpec getGcp();
  public GCPPlatformSpec buildGcp();
  public A withGcp(GCPPlatformSpec gcp);
  public Boolean hasGcp();
  public PlatformSpecFluent.GcpNested<A> withNewGcp();
  public PlatformSpecFluent.GcpNested<A> withNewGcpLike(GCPPlatformSpec item);
  public PlatformSpecFluent.GcpNested<A> editGcp();
  public PlatformSpecFluent.GcpNested<A> editOrNewGcp();
  public PlatformSpecFluent.GcpNested<A> editOrNewGcpLike(GCPPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildIbmcloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public IBMCloudPlatformSpec getIbmcloud();
  public IBMCloudPlatformSpec buildIbmcloud();
  public A withIbmcloud(IBMCloudPlatformSpec ibmcloud);
  public Boolean hasIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> withNewIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> withNewIbmcloudLike(IBMCloudPlatformSpec item);
  public PlatformSpecFluent.IbmcloudNested<A> editIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> editOrNewIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> editOrNewIbmcloudLike(IBMCloudPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildKubevirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public KubevirtPlatformSpec getKubevirt();
  public KubevirtPlatformSpec buildKubevirt();
  public A withKubevirt(KubevirtPlatformSpec kubevirt);
  public Boolean hasKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> withNewKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> withNewKubevirtLike(KubevirtPlatformSpec item);
  public PlatformSpecFluent.KubevirtNested<A> editKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> editOrNewKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> editOrNewKubevirtLike(KubevirtPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildOpenstack instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenStackPlatformSpec getOpenstack();
  public OpenStackPlatformSpec buildOpenstack();
  public A withOpenstack(OpenStackPlatformSpec openstack);
  public Boolean hasOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> withNewOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> withNewOpenstackLike(OpenStackPlatformSpec item);
  public PlatformSpecFluent.OpenstackNested<A> editOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> editOrNewOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> editOrNewOpenstackLike(OpenStackPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildOvirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public OvirtPlatformSpec getOvirt();
  public OvirtPlatformSpec buildOvirt();
  public A withOvirt(OvirtPlatformSpec ovirt);
  public Boolean hasOvirt();
  public PlatformSpecFluent.OvirtNested<A> withNewOvirt();
  public PlatformSpecFluent.OvirtNested<A> withNewOvirtLike(OvirtPlatformSpec item);
  public PlatformSpecFluent.OvirtNested<A> editOvirt();
  public PlatformSpecFluent.OvirtNested<A> editOrNewOvirt();
  public PlatformSpecFluent.OvirtNested<A> editOrNewOvirtLike(OvirtPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildPowervs instead.
   * @return The buildable object.
   */
  @Deprecated
  public PowerVSPlatformSpec getPowervs();
  public PowerVSPlatformSpec buildPowervs();
  public A withPowervs(PowerVSPlatformSpec powervs);
  public Boolean hasPowervs();
  public PlatformSpecFluent.PowervsNested<A> withNewPowervs();
  public PlatformSpecFluent.PowervsNested<A> withNewPowervsLike(PowerVSPlatformSpec item);
  public PlatformSpecFluent.PowervsNested<A> editPowervs();
  public PlatformSpecFluent.PowervsNested<A> editOrNewPowervs();
  public PlatformSpecFluent.PowervsNested<A> editOrNewPowervsLike(PowerVSPlatformSpec item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildVsphere instead.
   * @return The buildable object.
   */
  @Deprecated
  public VSpherePlatformSpec getVsphere();
  public VSpherePlatformSpec buildVsphere();
  public A withVsphere(VSpherePlatformSpec vsphere);
  public Boolean hasVsphere();
  public PlatformSpecFluent.VsphereNested<A> withNewVsphere();
  public PlatformSpecFluent.VsphereNested<A> withNewVsphereLike(VSpherePlatformSpec item);
  public PlatformSpecFluent.VsphereNested<A> editVsphere();
  public PlatformSpecFluent.VsphereNested<A> editOrNewVsphere();
  public PlatformSpecFluent.VsphereNested<A> editOrNewVsphereLike(VSpherePlatformSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AlibabaCloudNested<N> extends Nested<N>,AlibabaCloudPlatformSpecFluent<PlatformSpecFluent.AlibabaCloudNested<N>>{
    public N and();
    public N endAlibabaCloud();
    
  }
  public interface AwsNested<N> extends Nested<N>,AWSPlatformSpecFluent<PlatformSpecFluent.AwsNested<N>>{
    public N and();
    public N endAws();
    
  }
  public interface AzureNested<N> extends Nested<N>,AzurePlatformSpecFluent<PlatformSpecFluent.AzureNested<N>>{
    public N and();
    public N endAzure();
    
  }
  public interface BaremetalNested<N> extends Nested<N>,BareMetalPlatformSpecFluent<PlatformSpecFluent.BaremetalNested<N>>{
    public N and();
    public N endBaremetal();
    
  }
  public interface EquinixMetalNested<N> extends Nested<N>,EquinixMetalPlatformSpecFluent<PlatformSpecFluent.EquinixMetalNested<N>>{
    public N and();
    public N endEquinixMetal();
    
  }
  public interface GcpNested<N> extends Nested<N>,GCPPlatformSpecFluent<PlatformSpecFluent.GcpNested<N>>{
    public N and();
    public N endGcp();
    
  }
  public interface IbmcloudNested<N> extends Nested<N>,IBMCloudPlatformSpecFluent<PlatformSpecFluent.IbmcloudNested<N>>{
    public N and();
    public N endIbmcloud();
    
  }
  public interface KubevirtNested<N> extends Nested<N>,KubevirtPlatformSpecFluent<PlatformSpecFluent.KubevirtNested<N>>{
    public N and();
    public N endKubevirt();
    
  }
  public interface OpenstackNested<N> extends Nested<N>,OpenStackPlatformSpecFluent<PlatformSpecFluent.OpenstackNested<N>>{
    public N and();
    public N endOpenstack();
    
  }
  public interface OvirtNested<N> extends Nested<N>,OvirtPlatformSpecFluent<PlatformSpecFluent.OvirtNested<N>>{
    public N and();
    public N endOvirt();
    
  }
  public interface PowervsNested<N> extends Nested<N>,PowerVSPlatformSpecFluent<PlatformSpecFluent.PowervsNested<N>>{
    public N and();
    public N endPowervs();
    
  }
  public interface VsphereNested<N> extends Nested<N>,VSpherePlatformSpecFluent<PlatformSpecFluent.VsphereNested<N>>{
    public N and();
    public N endVsphere();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/PlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PlatformSpecFluent<A extends PlatformSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAlibabaCloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlibabaCloudPlatformSpec getAlibabaCloud();
  public AlibabaCloudPlatformSpec buildAlibabaCloud();
  public A withAlibabaCloud(AlibabaCloudPlatformSpec alibabaCloud);
  public Boolean hasAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> withNewAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> withNewAlibabaCloudLike(AlibabaCloudPlatformSpec item);
  public PlatformSpecFluent.AlibabaCloudNested<A> editAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> editOrNewAlibabaCloud();
  public PlatformSpecFluent.AlibabaCloudNested<A> editOrNewAlibabaCloudLike(AlibabaCloudPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildAws instead.
   * @return The buildable object.
   */
  @Deprecated
  public AWSPlatformSpec getAws();
  public AWSPlatformSpec buildAws();
  public A withAws(AWSPlatformSpec aws);
  public Boolean hasAws();
  public PlatformSpecFluent.AwsNested<A> withNewAws();
  public PlatformSpecFluent.AwsNested<A> withNewAwsLike(AWSPlatformSpec item);
  public PlatformSpecFluent.AwsNested<A> editAws();
  public PlatformSpecFluent.AwsNested<A> editOrNewAws();
  public PlatformSpecFluent.AwsNested<A> editOrNewAwsLike(AWSPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildAzure instead.
   * @return The buildable object.
   */
  @Deprecated
  public AzurePlatformSpec getAzure();
  public AzurePlatformSpec buildAzure();
  public A withAzure(AzurePlatformSpec azure);
  public Boolean hasAzure();
  public PlatformSpecFluent.AzureNested<A> withNewAzure();
  public PlatformSpecFluent.AzureNested<A> withNewAzureLike(AzurePlatformSpec item);
  public PlatformSpecFluent.AzureNested<A> editAzure();
  public PlatformSpecFluent.AzureNested<A> editOrNewAzure();
  public PlatformSpecFluent.AzureNested<A> editOrNewAzureLike(AzurePlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildBaremetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public BareMetalPlatformSpec getBaremetal();
  public BareMetalPlatformSpec buildBaremetal();
  public A withBaremetal(BareMetalPlatformSpec baremetal);
  public Boolean hasBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> withNewBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> withNewBaremetalLike(BareMetalPlatformSpec item);
  public PlatformSpecFluent.BaremetalNested<A> editBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> editOrNewBaremetal();
  public PlatformSpecFluent.BaremetalNested<A> editOrNewBaremetalLike(BareMetalPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildEquinixMetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public EquinixMetalPlatformSpec getEquinixMetal();
  public EquinixMetalPlatformSpec buildEquinixMetal();
  public A withEquinixMetal(EquinixMetalPlatformSpec equinixMetal);
  public Boolean hasEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> withNewEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> withNewEquinixMetalLike(EquinixMetalPlatformSpec item);
  public PlatformSpecFluent.EquinixMetalNested<A> editEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> editOrNewEquinixMetal();
  public PlatformSpecFluent.EquinixMetalNested<A> editOrNewEquinixMetalLike(EquinixMetalPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildGcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPPlatformSpec getGcp();
  public GCPPlatformSpec buildGcp();
  public A withGcp(GCPPlatformSpec gcp);
  public Boolean hasGcp();
  public PlatformSpecFluent.GcpNested<A> withNewGcp();
  public PlatformSpecFluent.GcpNested<A> withNewGcpLike(GCPPlatformSpec item);
  public PlatformSpecFluent.GcpNested<A> editGcp();
  public PlatformSpecFluent.GcpNested<A> editOrNewGcp();
  public PlatformSpecFluent.GcpNested<A> editOrNewGcpLike(GCPPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildIbmcloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public IBMCloudPlatformSpec getIbmcloud();
  public IBMCloudPlatformSpec buildIbmcloud();
  public A withIbmcloud(IBMCloudPlatformSpec ibmcloud);
  public Boolean hasIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> withNewIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> withNewIbmcloudLike(IBMCloudPlatformSpec item);
  public PlatformSpecFluent.IbmcloudNested<A> editIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> editOrNewIbmcloud();
  public PlatformSpecFluent.IbmcloudNested<A> editOrNewIbmcloudLike(IBMCloudPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildKubevirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public KubevirtPlatformSpec getKubevirt();
  public KubevirtPlatformSpec buildKubevirt();
  public A withKubevirt(KubevirtPlatformSpec kubevirt);
  public Boolean hasKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> withNewKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> withNewKubevirtLike(KubevirtPlatformSpec item);
  public PlatformSpecFluent.KubevirtNested<A> editKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> editOrNewKubevirt();
  public PlatformSpecFluent.KubevirtNested<A> editOrNewKubevirtLike(KubevirtPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildOpenstack instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenStackPlatformSpec getOpenstack();
  public OpenStackPlatformSpec buildOpenstack();
  public A withOpenstack(OpenStackPlatformSpec openstack);
  public Boolean hasOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> withNewOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> withNewOpenstackLike(OpenStackPlatformSpec item);
  public PlatformSpecFluent.OpenstackNested<A> editOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> editOrNewOpenstack();
  public PlatformSpecFluent.OpenstackNested<A> editOrNewOpenstackLike(OpenStackPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildOvirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public OvirtPlatformSpec getOvirt();
  public OvirtPlatformSpec buildOvirt();
  public A withOvirt(OvirtPlatformSpec ovirt);
  public Boolean hasOvirt();
  public PlatformSpecFluent.OvirtNested<A> withNewOvirt();
  public PlatformSpecFluent.OvirtNested<A> withNewOvirtLike(OvirtPlatformSpec item);
  public PlatformSpecFluent.OvirtNested<A> editOvirt();
  public PlatformSpecFluent.OvirtNested<A> editOrNewOvirt();
  public PlatformSpecFluent.OvirtNested<A> editOrNewOvirtLike(OvirtPlatformSpec item);
  
  /**
   * This method has been deprecated, please use method buildPowervs instead.
   * @return The buildable object.
   */
  @Deprecated
  public PowerVSPlatformSpec getPowervs();
  public PowerVSPlatformSpec buildPowervs();
  public A withPowervs(PowerVSPlatformSpec powervs);
  public Boolean hasPowervs();
  public PlatformSpecFluent.PowervsNested<A> withNewPowervs();
  public PlatformSpecFluent.PowervsNested<A> withNewPowervsLike(PowerVSPlatformSpec item);
  public PlatformSpecFluent.PowervsNested<A> editPowervs();
  public PlatformSpecFluent.PowervsNested<A> editOrNewPowervs();
  public PlatformSpecFluent.PowervsNested<A> editOrNewPowervsLike(PowerVSPlatformSpec item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildVsphere instead.
   * @return The buildable object.
   */
  @Deprecated
  public VSpherePlatformSpec getVsphere();
  public VSpherePlatformSpec buildVsphere();
  public A withVsphere(VSpherePlatformSpec vsphere);
  public Boolean hasVsphere();
  public PlatformSpecFluent.VsphereNested<A> withNewVsphere();
  public PlatformSpecFluent.VsphereNested<A> withNewVsphereLike(VSpherePlatformSpec item);
  public PlatformSpecFluent.VsphereNested<A> editVsphere();
  public PlatformSpecFluent.VsphereNested<A> editOrNewVsphere();
  public PlatformSpecFluent.VsphereNested<A> editOrNewVsphereLike(VSpherePlatformSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AlibabaCloudNested<N> extends Nested<N>,AlibabaCloudPlatformSpecFluent<PlatformSpecFluent.AlibabaCloudNested<N>>{
    public N and();
    public N endAlibabaCloud();
    
  }
  public interface AwsNested<N> extends Nested<N>,AWSPlatformSpecFluent<PlatformSpecFluent.AwsNested<N>>{
    public N and();
    public N endAws();
    
  }
  public interface AzureNested<N> extends Nested<N>,AzurePlatformSpecFluent<PlatformSpecFluent.AzureNested<N>>{
    public N and();
    public N endAzure();
    
  }
  public interface BaremetalNested<N> extends Nested<N>,BareMetalPlatformSpecFluent<PlatformSpecFluent.BaremetalNested<N>>{
    public N and();
    public N endBaremetal();
    
  }
  public interface EquinixMetalNested<N> extends Nested<N>,EquinixMetalPlatformSpecFluent<PlatformSpecFluent.EquinixMetalNested<N>>{
    public N and();
    public N endEquinixMetal();
    
  }
  public interface GcpNested<N> extends Nested<N>,GCPPlatformSpecFluent<PlatformSpecFluent.GcpNested<N>>{
    public N and();
    public N endGcp();
    
  }
  public interface IbmcloudNested<N> extends Nested<N>,IBMCloudPlatformSpecFluent<PlatformSpecFluent.IbmcloudNested<N>>{
    public N and();
    public N endIbmcloud();
    
  }
  public interface KubevirtNested<N> extends Nested<N>,KubevirtPlatformSpecFluent<PlatformSpecFluent.KubevirtNested<N>>{
    public N and();
    public N endKubevirt();
    
  }
  public interface OpenstackNested<N> extends Nested<N>,OpenStackPlatformSpecFluent<PlatformSpecFluent.OpenstackNested<N>>{
    public N and();
    public N endOpenstack();
    
  }
  public interface OvirtNested<N> extends Nested<N>,OvirtPlatformSpecFluent<PlatformSpecFluent.OvirtNested<N>>{
    public N and();
    public N endOvirt();
    
  }
  public interface PowervsNested<N> extends Nested<N>,PowerVSPlatformSpecFluent<PlatformSpecFluent.PowervsNested<N>>{
    public N and();
    public N endPowervs();
    
  }
  public interface VsphereNested<N> extends Nested<N>,VSpherePlatformSpecFluent<PlatformSpecFluent.VsphereNested<N>>{
    public N and();
    public N endVsphere();
    
  }
  
}
